@@ -634,7 +634,7 @@ static int generalMeshWrite(void *aimInfo, aimMesh *mesh)
     /* write all of the verticies */
     fprintf(fp, "POINTS %d double\n", meshData->nVertex);
     for (ivrtx = 0; ivrtx < meshData->nVertex; ivrtx++) {
-        fprintf(fp, "%16.8f %16.8f %16.8f\n",
+        fprintf(fp, "%20.16le %20.16le %20.16le\n",
                 meshData->verts[ivrtx][0],
                 meshData->verts[ivrtx][1],
                 meshData->verts[ivrtx][2]);
