@@ -9,7 +9,7 @@
  */
 
 /*
- * Copyright (C) 2013/2025  John F. Dannenhoffer, III (Syracuse University)
+ * Copyright (C) 2013/2026  John F. Dannenhoffer, III (Syracuse University)
  *
  * This library is free software; you can redistribute it and/or
  *    modify it under the terms of the GNU Lesser General Public
@@ -93,7 +93,7 @@ timLoad(esp_T *ESP,                     /* (in)  pointer to ESP structure */
     outLevel = ocsmSetOutLevel(-1);
 
     if (ESP == NULL) {
-        printf("ERROR:: cannot run timMitten without serveESP\n");
+        printf("ERROR:: cannot run timPlugs without serveESP\n");
         status = EGADS_SEQUERR;
         goto cleanup;
     }
